@@ -5,6 +5,7 @@ import asm.cms.cms
 import asm.cms.interfaces
 import asm.cmsui.form
 import grok
+import zope.interface
 
 
 grok.context(asm.cms.cms.CMS)
@@ -20,3 +21,9 @@ class PreviewWindow(grok.View):
     grok.name('preview-window')
     grok.template('preview-window')
 
+
+class ToolActions(grok.Viewlet):
+
+    grok.template('actions')
+    grok.viewletmanager(asm.cmsui.base.NavigationToolActions)
+    grok.context(zope.interface.Interface)
