@@ -1,11 +1,13 @@
 # Copyright (c) 2010 gocept gmbh & co. kg
 # See also LICENSE.txt
 
-import megrok.pagelet
-import grok
 import asm.cms.cms
 import asm.cmsui.interfaces
+import grok
 import hurry.query.query
+import simplejson
+import megrok.pagelet
+import zope.component
 import zope.index.text.parsetree
 
 class Search(megrok.pagelet.Pagelet):
@@ -24,11 +26,7 @@ class Search(megrok.pagelet.Pagelet):
             self.results = []
 
 
-class PublicSearch(megrok.pagelet.Pagelet):
-
-    grok.context(asm.cms.interfaces.IEdition)
-    grok.layer(asm.cmsui.interfaces.IRetailSkin)
-    grok.name('search')
+class SearchBase(object):
 
     def update(self):
         self.keyword = q = self.request.form.get('q', '')
@@ -47,6 +45,42 @@ class PublicSearch(megrok.pagelet.Pagelet):
                 self.results.append(result)
 
 
+class PublicSearch(SearchBase, megrok.pagelet.Pagelet):
+
+    grok.context(asm.cms.interfaces.IEdition)
+    grok.layer(asm.cmsui.interfaces.IRetailSkin)
+    grok.name('search')
+
+    def sites(self):
+        return asm.cms.interfaces.ISearchSites(self.application).sites
+
+
+class PublicJsonSearch(SearchBase, grok.View):
+
+    grok.context(asm.cms.interfaces.IEdition)
+    grok.layer(asm.cmsui.interfaces.IRetailSkin)
+    grok.name('search.json')
+
+    def render(self):
+        output = []
+        for edition in self.results:
+            preview = ""
+            try:
+                view = zope.component.getMultiAdapter(
+                    (edition, self.request), name="searchpreview")
+                preview = view()
+            except LookupError:
+                pass
+
+            output.append({
+                    'title': edition.title,
+                    'url': self.url(edition),
+                    'content': preview,
+                    })
+
+        return simplejson.dumps(output)
+
+
 class OSDDEdition(grok.View):
     grok.context(asm.cms.interfaces.IEdition)
     grok.name("osdd.xml")
@@ -64,3 +98,9 @@ class OSDDCMS(grok.View):
     def title(self):
         edition = asm.cms.edition.select_edition(self.context, self.request)
         return edition.title + u" CMS"
+
+
+class SelectSearchSites(asm.cmsui.form.EditForm):
+
+    form_fields = grok.AutoFields(asm.cms.interfaces.ISearchSites)
+    grok.context(asm.cms.cms.CMS)
