@@ -2,25 +2,13 @@
 # See also LICENSE.txt
 
 import zope.app.form.browser.textwidgets
-import hurry.tinymce.tinymce
-import hurry.resource
 import asm.cms.interfaces
 import grok
 
-widget_lib = hurry.resource.Library('asm.cmsui')
-widget = hurry.resource.ResourceInclusion(widget_lib, 'tinymce_widget.js',
-                                 depends=[hurry.tinymce.tinymce],
-                                 bottom=True)
-
-popup = hurry.resource.ResourceInclusion(
-    hurry.tinymce.tinymce_lib, 'tiny_mce_popup.js')
-
 
 class TinyMCEWidget(zope.app.form.browser.textwidgets.TextAreaWidget):
 
     def __call__(self):
-        widget.need()
-        hurry.resource.bottom(force=True)
         self.cssClass += ' mceEditor'
         return super(TinyMCEWidget, self).__call__()
 
@@ -31,10 +19,6 @@ class TinyMCELinkBrowser(grok.View):
     grok.name('tinymce-linkbrowser')
     grok.template('linkbrowser')
 
-    def __call__(self):
-        popup.need()
-        return super(TinyMCELinkBrowser, self).__call__()
-
     def pages(self):
         # Return a set of editions representing the pages
         for page in self.context.subpages:
